@@ -195,23 +195,23 @@ unsafe fn key_input(hwnd: HWND, msg: u32, wparam: WPARAM, lparam: LPARAM) -> LRE
     };
     let scan_code = ((lparam.0 >> 16) & 0xff) as u32;
     let extended = (lparam.0 >> 24) & 0x01 != 0;
-    let vkey = match VIRTUAL_KEY(wparam.0 as _) {
+    let vkey = match wparam.0 as _ {
         VK_SHIFT => MapVirtualKeyW(scan_code, MAPVK_VSC_TO_VK_EX),
         VK_CONTROL => {
             if extended {
-                VK_RCONTROL.0 as _
+                VK_RCONTROL as _
             } else {
-                VK_LCONTROL.0 as _
+                VK_LCONTROL as _
             }
         }
         VK_MENU => {
             if extended {
-                VK_RMENU.0 as _
+                VK_RMENU as _
             } else {
-                VK_LMENU.0 as _
+                VK_LMENU as _
             }
         }
-        v => v.0 as _,
+        v => v as _,
     };
     let key_code = KeyCode {
         vkey: VirtualKeyCode(vkey),
@@ -283,7 +283,7 @@ unsafe fn wm_ime_composition(hwnd: HWND, wparam: WPARAM, lparam: LPARAM) -> LRES
         None => return DefWindowProcW(hwnd, WM_IME_COMPOSITION, wparam, lparam),
     };
     let imc = ime::Imc::get(hwnd);
-    if lparam.0 as u32 & GCS_RESULTSTR == GCS_RESULTSTR {
+    if (lparam.0 as u32) & GCS_RESULTSTR == GCS_RESULTSTR {
         let comp_str = imc.get_composition_string(GCS_RESULTSTR);
         if let Some(ime::CompositionString::CompStr(s)) = comp_str {
             let comp_attr = imc.get_composition_string(GCS_COMPATTR);
@@ -294,7 +294,7 @@ unsafe fn wm_ime_composition(hwnd: HWND, wparam: WPARAM, lparam: LPARAM) -> LRES
             }
         }
     }
-    if lparam.0 as u32 & GCS_COMPSTR == GCS_COMPSTR {
+    if (lparam.0 as u32) & GCS_COMPSTR == GCS_COMPSTR {
         let comp_str = imc.get_composition_string(GCS_COMPSTR);
         if let Some(ime::CompositionString::CompStr(s)) = comp_str {
             let comp_attr = imc.get_composition_string(GCS_COMPATTR);
@@ -411,8 +411,8 @@ unsafe fn wm_get_dpi_scaled_size(hwnd: HWND, wparam: WPARAM, lparam: LPARAM) ->
     ));
     let size = utility::adjust_window_size(
         size,
-        WINDOW_STYLE(GetWindowLongPtrW(hwnd, GWL_STYLE) as _),
-        WINDOW_EX_STYLE(GetWindowLongPtrW(hwnd, GWL_EXSTYLE) as _),
+        GetWindowLongPtrW(hwnd, GWL_STYLE) as _,
+        GetWindowLongPtrW(hwnd, GWL_EXSTYLE) as _,
         next_dpi as _,
     );
     let mut ret = (lparam.0 as *mut SIZE).as_mut().unwrap();
