@@ -2,7 +2,6 @@ use super::*;
 use once_cell::sync::OnceCell;
 use tokio::sync::{mpsc, oneshot};
 use windows::{
-    core::Handle,
     Win32::{
         Foundation::*,
         Graphics::Gdi::*,
@@ -21,7 +20,7 @@ pub struct BorderlessStyle;
 
 impl StyleObject for BorderlessStyle {
     fn value(&self) -> u32 {
-        WS_POPUP.0
+        WS_POPUP
     }
 
     fn ex(&self) -> u32 {
@@ -39,7 +38,7 @@ impl Style {
     #[inline]
     pub const fn new() -> Self {
         Self {
-            value: WS_OVERLAPPEDWINDOW.0,
+            value: WS_OVERLAPPEDWINDOW,
             ex: 0,
         }
     }
@@ -47,7 +46,7 @@ impl Style {
     #[inline]
     pub const fn dialog() -> Self {
         Self {
-            value: WS_OVERLAPPED.0 | WS_CAPTION.0 | WS_SYSMENU.0,
+            value: WS_OVERLAPPED | WS_CAPTION | WS_SYSMENU,
             ex: 0,
         }
     }
@@ -60,9 +59,9 @@ impl Style {
     #[inline]
     pub const fn resizable(mut self, resizable: bool) -> Self {
         if resizable {
-            self.value |= WS_THICKFRAME.0;
+            self.value |= WS_THICKFRAME;
         } else {
-            self.value &= !WS_THICKFRAME.0;
+            self.value &= !WS_THICKFRAME;
         }
         self
     }
@@ -70,9 +69,9 @@ impl Style {
     #[inline]
     pub const fn has_minimize_box(mut self, flag: bool) -> Self {
         if flag {
-            self.value |= WS_MINIMIZEBOX.0;
+            self.value |= WS_MINIMIZEBOX;
         } else {
-            self.value &= !WS_MINIMIZEBOX.0;
+            self.value &= !WS_MINIMIZEBOX;
         }
         self
     }
@@ -80,9 +79,9 @@ impl Style {
     #[inline]
     pub const fn has_maximize_box(mut self, flag: bool) -> Self {
         if flag {
-            self.value |= WS_MAXIMIZEBOX.0;
+            self.value |= WS_MAXIMIZEBOX;
         } else {
-            self.value &= !WS_MAXIMIZEBOX.0;
+            self.value &= !WS_MAXIMIZEBOX;
         }
         self
     }
@@ -90,9 +89,9 @@ impl Style {
     #[inline]
     pub const fn no_redirection_bitmap(mut self, flag: bool) -> Self {
         if flag {
-            self.ex |= WS_EX_NOREDIRECTIONBITMAP.0;
+            self.ex |= WS_EX_NOREDIRECTIONBITMAP;
         } else {
-            self.ex &= !WS_EX_NOREDIRECTIONBITMAP.0;
+            self.ex &= !WS_EX_NOREDIRECTIONBITMAP;
         }
         self
     }
@@ -314,12 +313,12 @@ impl Window {
                 .collect::<Vec<_>>();
             let size = builder.size.to_physical(dpi);
             let size =
-                utility::adjust_window_size(size, WS_OVERLAPPEDWINDOW, WINDOW_EX_STYLE(0), dpi);
+                utility::adjust_window_size(size, WS_OVERLAPPEDWINDOW, 0, dpi);
             let hwnd = CreateWindowExW(
-                WINDOW_EX_STYLE(builder.style.ex),
+                builder.style.ex,
                 PWSTR(window_class().as_ptr() as _),
                 PWSTR(title.as_ptr() as _),
-                WINDOW_STYLE(builder.style.value),
+                builder.style.value,
                 builder.position.x,
                 builder.position.y,
                 size.width as _,
@@ -329,19 +328,19 @@ impl Window {
                 GetModuleHandleW(None),
                 std::ptr::null_mut(),
             );
-            if hwnd.is_invalid() {
+            if hwnd == HWND::default() {
                 tx.send(Err(windows::core::Error::from_win32().into())).ok();
                 return;
             }
             if let Some(icon) = builder.icon {
-                let big = icon.load().unwrap();
-                SendMessageW(hwnd, WM_SETICON, WPARAM(ICON_BIG as _), LPARAM(big.0 as _));
-                let small = icon.load_small().unwrap();
+                let big = LPARAM(icon.load().unwrap().0 as _);
+                SendMessageW(hwnd, WM_SETICON, WPARAM(ICON_BIG as _), big);
+                let small = LPARAM(icon.load_small().unwrap().0 as _);
                 SendMessageW(
                     hwnd,
                     WM_SETICON,
                     WPARAM(ICON_SMALL as _),
-                    LPARAM(small.0 as _),
+                    small,
                 );
             }
             DragAcceptFiles(hwnd, builder.accept_drop_files);
